# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderMfaRequestMethod(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SMS = "sms"
    EMAIL = "email"

    def visit(self, sms: typing.Callable[[], T_Result], email: typing.Callable[[], T_Result]) -> T_Result:
        if self is ProviderMfaRequestMethod.SMS:
            return sms()
        if self is ProviderMfaRequestMethod.EMAIL:
            return email()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class BulkOpType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    LINK_BULK_IMPORT = "link_bulk_import"
    LINK_BULK_HISTORICAL_TRIGGER = "link_bulk_historical_trigger"

    def visit(
        self,
        link_bulk_import: typing.Callable[[], T_Result],
        link_bulk_historical_trigger: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is BulkOpType.LINK_BULK_IMPORT:
            return link_bulk_import()
        if self is BulkOpType.LINK_BULK_HISTORICAL_TRIGGER:
            return link_bulk_historical_trigger()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_provider import ClientFacingProvider
from .client_facing_sport import ClientFacingSport


class WorkoutV2InDb(UniversalBaseModel):
    timestamp: dt.datetime
    data: typing.Dict[str, typing.Optional[typing.Any]]
    provider_id: str
    user_id: str
    source_id: int
    priority_id: typing.Optional[int] = None
    id: str
    sport_id: int
    source: ClientFacingProvider
    sport: ClientFacingSport
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .date_part_expr import DatePartExpr
from .date_trunc_expr import DateTruncExpr

QueryGroupByItem = typing.Union[DateTruncExpr, DatePartExpr]
